# Table of Contents

- [setting-up-your-custom-reports-project](<./setting-up-your-custom-reports-project.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Setting Up Your Custom Reports Project](<./Setting-Up-Your-Custom-Reports-Project.md>)
  - [Overview](<./Setting-Up-Your-Custom-Reports-Project/Overview.md>)
  - [Prerequisites](<./Setting-Up-Your-Custom-Reports-Project/Prerequisites.md>)
  - [Step 1: Install the LeanIX Reporting CLI](<./Setting-Up-Your-Custom-Reports-Project/Step-1-Install-the-LeanIX-Reporting-CLI.md>)
  - [Step 2: Create Your Project Directory](<./Setting-Up-Your-Custom-Reports-Project/Step-2-Create-Your-Project-Directory.md>)
  - [Step 3: Scaffold Your Project](<./Setting-Up-Your-Custom-Reports-Project/Step-3-Scaffold-Your-Project.md>)
  - [Step 4: Configure Your Project](<./Setting-Up-Your-Custom-Reports-Project/Step-4-Configure-Your-Project.md>)
  - [Step 5: Install Dependencies](<./Setting-Up-Your-Custom-Reports-Project/Step-5-Install-Dependencies.md>)
  - [Step 6: Install Chart.js](<./Setting-Up-Your-Custom-Reports-Project/Step-6-Install-Chart.js.md>)
  - [Step 7: Install Tailwind CSS](<./Setting-Up-Your-Custom-Reports-Project/Step-7-Install-Tailwind-CSS.md>)
  - [Step 8: Verify Your Project Setup](<./Setting-Up-Your-Custom-Reports-Project/Step-8-Verify-Your-Project-Setup.md>)
  - [Troubleshooting: Bypassing Browser Errors for Self-Signed Certificates](<./Setting-Up-Your-Custom-Reports-Project/Troubleshooting-Bypassing-Browser-Errors-for-Self-Signed-Certificates.md>)
  - [Summary](<./Setting-Up-Your-Custom-Reports-Project/Summary.md>)
  - [Next Steps](<./Setting-Up-Your-Custom-Reports-Project/Next-Steps.md>)
  - [Was this page helpful?](<./Setting-Up-Your-Custom-Reports-Project/Was-this-page-helpful.md>)
